@@ -1,10 +1,10 @@
-import numpy as np
-
+from random import choice
 from poker_game_runner.state import Observation
 
+
 class Bot:
-    def get_name(self):    
+    def get_name(self):
         return "randomBot"
 
     def act(self, observation: Observation):
-        return np.random.choice(observation.legal_actions)
\ No newline at end of file
+        return choice(observation.legal_actions)
